@@ -1,21 +1,27 @@
+from typing import TypeVar
+import lazy_import
+
 import ujson
-import pydash
+
+pydash = lazy_import.lazy_module("pydash")
 import phpserialize
 import regex as re
 from lxml import etree
 from ..core import ChepyCore, ChepyDecorators
 
+CodeTidyT = TypeVar("CodeTidyT", bound="CodeTidy")
+
 
 class CodeTidy(ChepyCore):
     def __init__(self, *data):
         super().__init__(*data)
 
     @ChepyDecorators.call_stack
-    def minify_json(self):
+    def minify_json(self) -> CodeTidyT:
         """Minify JSON string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("/path/to/file.json").load_file()
@@ -25,14 +31,14 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def beautify_json(self, indent: int = 2):
+    def beautify_json(self, indent: int = 2) -> CodeTidyT:
         """Beautify minified JSON
-        
+
         Args:
             indent (int, optional): Indent level. Defaults to 2.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("/path/to/file.json").load_file()
@@ -42,12 +48,12 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def minify_xml(self):
+    def minify_xml(self) -> CodeTidyT:
         """Minify XML string
-        
+
         Returns:
-            Chepy: The Chepy object. 
-        
+            Chepy: The Chepy object.
+
         Examples:
             >>> c = Chepy("/path/to/file.xml").load_file()
             >>> print(c.minify_xml())
@@ -59,11 +65,11 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def beautify_xml(self):
+    def beautify_xml(self) -> CodeTidyT:
         """Beautify compressed XML
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("/path/to/file.xml").load_file()
@@ -75,13 +81,13 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def php_deserialize(self):
+    def php_deserialize(self) -> CodeTidyT:
         """Deserialize php to dict
-        
+
         Deserializes PHP serialized data, outputting keyed arrays as a python dict.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy('a:3:{i:1;s:6:"elem 1";i:2;s:6:"elem 2";i:3;s:7:" elem 3";}')
@@ -92,12 +98,12 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_upper_case(self, by: str = "all"):
+    def to_upper_case(self, by: str = "all") -> CodeTidyT:
         """Convert string to uppercase
-        
+
         Args:
             by (str, optional): Convert all, by word or by sentence. Defaults to 'all'.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -106,12 +112,12 @@ class CodeTidy(ChepyCore):
 
             >>> Chepy("some String").to_upper_case(by="word").o
             "Some String"
-            
+
             Uppercase by sentence
 
             >>> Chepy("some String").to_upper_case(by="sentence").o
             "Some string"
-            
+
             Uppercase all
 
             >>> Chepy("some String").to_upper_case(by="all").o
@@ -131,11 +137,11 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_lower_case(self):
+    def to_lower_case(self) -> CodeTidyT:
         """Convert string to lowercase
 
         Converts every character in the input to lower case.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -147,10 +153,10 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_snake_case(self):
+    def to_snake_case(self) -> CodeTidyT:
         """Convert string to snake case
 
-        Converts the input string to snake case. Snake case is all lower case 
+        Converts the input string to snake case. Snake case is all lower case
         with underscores as word boundaries. e.g. this_is_snake_case.
 
         Returns:
@@ -165,22 +171,22 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_camel_case(self, ignore_space: bool = False):
+    def to_camel_case(self, ignore_space: bool = False) -> CodeTidyT:
         """Convert string to camel case
-        
-        Converts the input string to camel case. Camel case is all lower case 
-        except letters after word boundaries which are uppercase. e.g. thisIsCamelCase 
+
+        Converts the input string to camel case. Camel case is all lower case
+        except letters after word boundaries which are uppercase. e.g. thisIsCamelCase
 
         Args:
             ignore_space (bool, optional): Ignore space boundaries. Defaults to False.
-        
+
         Returns:
             Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some Data_test").to_camel_case().o
             "someDataTest"
-            
+
             To ignore space, we can set the `ignore_space` to True
             >>> Chepy("some Data_test").to_camel_case(ignore_space=True).o
             "some DataTest"
@@ -193,16 +199,16 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_kebab_case(self):
+    def to_kebab_case(self) -> CodeTidyT:
         """Convert string to kebab case
 
-        Converts the input string to kebab case. Kebab case is all lower case 
+        Converts the input string to kebab case. Kebab case is all lower case
         with dashes as word boundaries. e.g. this-is-kebab-case.
 
         Returns:
             Chepy: The Chepy object.
 
-        Examples:  
+        Examples:
             >>> Chepy("Some data_test").to_kebab_case().o
             "some-data-test"
         """
@@ -210,9 +216,9 @@ class CodeTidy(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def swap_case(self):
+    def swap_case(self) -> CodeTidyT:
         """Swap case in a string
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -222,3 +228,31 @@ class CodeTidy(ChepyCore):
         """
         self.state = pydash.swap_case(self._convert_to_str())
         return self
+
+    @ChepyDecorators.call_stack
+    def to_leetspeak(self, special_chars: bool = True) -> CodeTidyT:
+        """Convert string to l33t speak
+
+        Args:
+            special_chars (bool, optional): Use special chars in conversion. Defaults to True.
+
+        Returns:
+            Chepy: The Chepy object
+
+        Examples:
+            >>> Chepy("somexValue").to_leetspeak().o
+            "50m3%V@1u3"
+        """
+        chars = {"B": "8", "E": "3", "L": "1", "O": "0", "S": "5", "T": "7", "Z": "2"}
+        special = {"A": "@", "C": "(", "I": "!", "X": "%"}
+        if special_chars:
+            chars = {**chars, **special}
+        hold = ""
+        for char in list(self._convert_to_str()):
+            upper = char.upper()
+            if chars.get(upper):
+                hold += chars.get(upper)
+            else:
+                hold += char
+        self.state = hold
+        return self
