@@ -1,33 +1,61 @@
+import lazy_import
 import binascii
 import base64
 import codecs
 import html
 import base58
 import ujson
-import yaml
+
+yaml = lazy_import.lazy_module("yaml")
 import regex as re
 import hexdump
-from typing import Union
+from ast import literal_eval
+from typing import TypeVar, Union
 from urllib.parse import quote_plus as _urllib_quote_plus
 from urllib.parse import unquote_plus as _urllib_unquote_plus
 
 from ..core import ChepyCore, ChepyDecorators
 from chepy.modules.internal.constants import Encoding
 
+DataFormatT = TypeVar("DataFormatT", bound="DataFormat")
+
 
 class DataFormat(ChepyCore):
     def __init__(self, *data):
         super().__init__(*data)
 
     @ChepyDecorators.call_stack
-    def list_to_str(self, join_by: Union[str, bytes]=" "):
+    def eval_state(self) -> DataFormatT:
+        """Eval state as python.
+        Handy when converting string representation
+        of objects.
+
+        Returns:
+            Chepy: The Chepy object
+        """
+        self.state = literal_eval(self.state)
+        return self
+
+    @ChepyDecorators.call_stack
+    def bytes_to_ascii(self) -> DataFormatT:
+        """Convert bytes (array of bytes) to ascii
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        assert isinstance(self.state, list), "Data in state is not a list"
+        self.state = bytearray(self.state).decode()
+        return self
+
+    @ChepyDecorators.call_stack
+    def list_to_str(self, join_by: Union[str, bytes] = " ") -> DataFormatT:
         """Join an array by `join_by`
-        
+
         Args:
             join_by (Union[str, bytes], optional): String character to join by, by default ' '
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(["a", "b", "c"]).list_to_str(",").o
@@ -38,9 +66,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def str_list_to_list(self):
+    def str_list_to_list(self) -> DataFormatT:
         """Convert a string list to a list
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -52,14 +80,14 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def join_list(self, by: Union[str, bytes] = ""):
+    def join_list(self, by: Union[str, bytes] = "") -> DataFormatT:
         """Join a list with specified character
-        
+
         Args:
             by (Union[str, bytes], optional): What to join with. Defaults to ""
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         Examples:
             >>> Chepy(["a", "b", "c"]).join_list(":").o
             "a:b:c"
@@ -68,9 +96,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def json_to_dict(self):
+    def json_to_dict(self) -> DataFormatT:
         """Convert a JSON string to a dict object
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -85,9 +113,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def dict_to_json(self):
+    def dict_to_json(self) -> DataFormatT:
         """Convert a dict object to a JSON string
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -100,9 +128,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def yaml_to_json(self):
+    def yaml_to_json(self) -> DataFormatT:
         """Convert yaml to a json string
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -110,14 +138,20 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def json_to_yaml(self):
+    def json_to_yaml(self) -> DataFormatT:
         """Convert a json string to yaml structure
-        
+
         Returns:
             Chepy: The Chepy object.
         """
+
+        class ChepyYamlDumper(yaml.Dumper):
+            def increase_indent(self, flow=False, indentless=False):
+                return super(ChepyYamlDumper, self).increase_indent(flow, False)
+
         self.state = yaml.dump(
             ujson.loads(self.state),
+            Dumper=ChepyYamlDumper,
             default_flow_style=False,
             sort_keys=False,
             allow_unicode=True,
@@ -125,16 +159,16 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base58_encode(self):
+    def base58_encode(self) -> DataFormatT:
         """Encode as Base58
-        
-        Base58 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers.This property encodes raw data 
+
+        Base58 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers.This property encodes raw data
         into an ASCII Base58 string.
 
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").base58_encode().output.decode()
@@ -144,16 +178,16 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base58_decode(self):
+    def base58_decode(self) -> DataFormatT:
         """Decode as Base58
-        
-        Base58 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers.This property decodes raw data 
+
+        Base58 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers.This property decodes raw data
         into an ASCII Base58 string.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("2UDrs31qcWSPi").base58_decode().output.decode()
@@ -163,16 +197,16 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base85_encode(self):
+    def base85_encode(self) -> DataFormatT:
         """Encode as Base58
 
-        Base85 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers.This property decodes raw data 
+        Base85 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers.This property decodes raw data
         into an ASCII Base58 string.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").base85_encode().output.decode()
@@ -182,16 +216,16 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base85_decode(self):
+    def base85_decode(self) -> DataFormatT:
         """Decode as Base85
 
-        Base85 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers.This property decodes raw data 
+        Base85 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers.This property decodes raw data
         into an ASCII Base58 string.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("F)Po,+Cno&@/").base85_decode().output.decode()
@@ -201,16 +235,36 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base32_encode(self):
-        """Encode as Base32
-        
-        Base32 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers. It uses a smaller set of characters than 
-        Base64, usually the uppercase alphabet and the numbers 2 to 7.
-        
+    def base16_encode(self) -> DataFormatT:
+        """Encode state in base16
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
+        """
+        self.state = base64.b16encode(self._convert_to_bytes())
+        return self
+
+    @ChepyDecorators.call_stack
+    def base16_decode(self) -> DataFormatT:
+        """Decode state in base16
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        self.state = base64.b16decode(self._convert_to_bytes())
+        return self
+
+    @ChepyDecorators.call_stack
+    def base32_encode(self) -> DataFormatT:
+        """Encode as Base32
+
+        Base32 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers. It uses a smaller set of characters than
+        Base64, usually the uppercase alphabet and the numbers 2 to 7.
+
+        Returns:
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").base32_encode().output.decode()
@@ -220,24 +274,24 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base32_decode(self):
+    def base32_decode(self) -> DataFormatT:
         """Decode as Base32
-        
-        Base32 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers. It uses a smaller set of characters than 
+
+        Base32 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers. It uses a smaller set of characters than
         Base64, usually the uppercase alphabet and the numbers 2 to 7.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = base64.b32decode(self.state)
         return self
 
     @ChepyDecorators.call_stack
-    def to_int(self):
+    def to_int(self) -> DataFormatT:
         """Converts the string representation of a number into an int
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -249,9 +303,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_bytes(self):
+    def to_bytes(self) -> DataFormatT:
         """Converts the data in state to bytes
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -263,9 +317,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_bytes(self):
+    def from_bytes(self) -> DataFormatT:
         """Decodes bytes to string.
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -273,20 +327,20 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base64_encode(self, custom: str = None):
+    def base64_encode(self, custom: str = None) -> DataFormatT:
         """Encode as Base64
-        
-        Base64 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers.This property encodes raw data 
+
+        Base64 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers.This property encodes raw data
         into an ASCII Base64 string.
 
         Args:
             custom (str, optional): Provide a custom charset to base64 with
-        
+
         Returns:
-            Chepy: The Chepy object. 
-        
+            Chepy: The Chepy object.
+
         Examples:
             >>> # To use a custom character set, use:
             >>> custom = "./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
@@ -307,20 +361,22 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def base64_decode(self, custom: str = None, fix_padding: bool = True):
+    def base64_decode(
+        self, custom: str = None, fix_padding: bool = True
+    ) -> DataFormatT:
         """Decode as Base64
 
-        Base64 is a notation for encoding arbitrary byte data using a 
-        restricted set of symbols that can be conveniently used by humans 
-        and processed by computers.This property decodes raw data 
+        Base64 is a notation for encoding arbitrary byte data using a
+        restricted set of symbols that can be conveniently used by humans
+        and processed by computers.This property decodes raw data
         into an ASCII Base64 string.
 
         Args:
             custom (str, optional): Provide a custom charset to base64 with
             fix_padding (bool, optional): If padding error, add padding. Defaults to True
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             Base64 decode using a custom string
@@ -351,11 +407,24 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_hex(self):
-        """Converts a string to its hex representation
-        
+    def decode_bytes(self, errors: str = "ignore") -> DataFormatT:
+        """Decode bytes to string
+
+        Args:
+            errors (str, optional): Ignore or replace error chars. Defaults to 'ignore'.
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
+        """
+        self.state = self._convert_to_bytes().decode(errors=errors)
+        return self
+
+    @ChepyDecorators.call_stack
+    def to_hex(self) -> DataFormatT:
+        """Converts a string to its hex representation
+
+        Returns:
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("AAA").to_hex().out().decode()
@@ -365,11 +434,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_hex(self):
+    def from_hex(self) -> DataFormatT:
         """Convert a non delimited hex string to string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("414141").from_hex().out()
@@ -379,18 +448,18 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def hex_to_int(self):
+    def hex_to_int(self) -> DataFormatT:
         """Converts hex into its intiger represantation
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             Chepy works with hex characters that start with a 0x
 
             >>> Chepy("0x123").hex_to_int().output
             291
-            
+
             Without 0x in the hex
 
             >>> Chepy("123").hex_to_int().output
@@ -403,14 +472,14 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def hex_to_binary(self):
+    def hex_to_binary(self) -> DataFormatT:
         """Hex to binary hex
-        
-        Converts a hex string to its binary form. Example: 
+
+        Converts a hex string to its binary form. Example:
         41 becomes \\x41
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("ab00").hex_to_binary().o
@@ -420,19 +489,19 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def hex_to_str(self, ignore: bool = False):
+    def hex_to_str(self, ignore: bool = False) -> DataFormatT:
         """Decodes a hex string to ascii ignoring any decoding errors
-        
+
         Args:
             ignore (bool, optional): Ignore errors, by default False
-        
+
         Returns:
             Chepy: The Chepy object.
 
         Examples:
             To ignore UnicodeDecode errors, set ignore to True
             >>> Chepy("4100").hex_to_str(ignore=True).o
-            "A\x00" 
+            "A\x00"
         """
         if ignore:
             self.state = binascii.unhexlify(self._convert_to_bytes()).decode(
@@ -443,21 +512,21 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def str_to_hex(self):
+    def str_to_hex(self) -> DataFormatT:
         """Converts a string to a hex string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = binascii.hexlify(self._convert_to_bytes())
         return self
 
     @ChepyDecorators.call_stack
-    def int_to_hex(self):
+    def int_to_hex(self) -> DataFormatT:
         """Converts an integer into its hex equivalent
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(101).int_to_hex().o
@@ -467,37 +536,37 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def int_to_str(self):
+    def int_to_str(self) -> DataFormatT:
         """Converts an integer into a string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = self._convert_to_str()
         return self
 
     @ChepyDecorators.call_stack
-    def binary_to_hex(self):
+    def binary_to_hex(self) -> DataFormatT:
         """Converts binary data into a hex string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = binascii.hexlify(self._convert_to_bytes())
         return self
 
     @ChepyDecorators.call_stack
-    def normalize_hex(self, is_bytearray=False):
+    def normalize_hex(self, is_bytearray=False) -> DataFormatT:
         """Normalize a hex string
-        
-        Removes special encoding characters from a hex string like %, 
+
+        Removes special encoding characters from a hex string like %,
         0x, , :, ;, \\n and \\r\\n
 
         Args:
             is_bytearray (bool, optional): Set to True if state is a bytearray
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("41:42:CE").normalize_hex().o
@@ -515,9 +584,9 @@ class DataFormat(ChepyCore):
             return self
 
     @ChepyDecorators.call_stack
-    def str_from_hexdump(self):
+    def str_from_hexdump(self) -> DataFormatT:
         """Extract a string from a hexdump
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -526,37 +595,37 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_hexdump(self):
+    def to_hexdump(self) -> DataFormatT:
         """Convert the state to hexdump
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = hexdump.hexdump(self._convert_to_bytes(), result="return")
         return self
 
     @ChepyDecorators.call_stack
-    def from_hexdump(self):
+    def from_hexdump(self) -> DataFormatT:
         """Convert hexdump back to str
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = hexdump.restore(self._convert_to_str())
         return self
 
     @ChepyDecorators.call_stack
-    def url_encode(self, safe: str = ""):
+    def url_encode(self, safe: str = "") -> DataFormatT:
         """URL encode
-        
-        Encodes problematic characters into percent-encoding, 
+
+        Encodes problematic characters into percent-encoding,
         a format supported by URIs/URLs.
-        
+
         Args:
             safe (str, optional): String of characters that will not be encoded, by default ""
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             Url encode while specifying save characters
@@ -568,9 +637,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def url_decode(self):
+    def url_decode(self) -> DataFormatT:
         """Converts URI/URL percent-encoded characters back to their raw values.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -582,13 +651,15 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def bytearray_to_str(self, encoding: str = "utf8", errors: str = "replace"):
+    def bytearray_to_str(
+        self, encoding: str = "utf8", errors: str = "replace"
+    ) -> DataFormatT:
         """Convert a python bytearray to string
-        
+
         Args:
             encoding (str, optional): String encoding. Defaults to 'utf8'.
-            errors (str, optional): How errors should be handled. Defaults to replace. 
-        
+            errors (str, optional): How errors should be handled. Defaults to replace.
+
         Raises:
             TypeError: If state is not a bytearray
 
@@ -606,11 +677,11 @@ class DataFormat(ChepyCore):
             raise TypeError("State is not a bytearray")
 
     @ChepyDecorators.call_stack
-    def str_to_list(self):
+    def str_to_list(self) -> DataFormatT:
         """Convert string to list
 
         Converts the string in state to an array of individual characyers
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -622,9 +693,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def str_to_dict(self):
+    def str_to_dict(self) -> DataFormatT:
         """Convert string to a dictionary
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -632,20 +703,20 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_charcode(self, escape_char: str = ""):
+    def to_charcode(self, escape_char: str = "") -> DataFormatT:
         """Convert a string to a list of unicode charcode
 
         Converts text to its unicode character code equivalent.
         e.g. Γειά σου becomes 0393 03b5 03b9 03ac 20 03c3 03bf 03c5
 
         Args:
-            escape_char (str, optional): Charcater to prepend with. Example \\u, u etc. 
+            escape_char (str, optional): Charcater to prepend with. Example \\u, u etc.
                 @ChepyDecorators.call_stack
                 Defaults to ''
-        
+
         Returns:
-            Chepy: The Chepy object. 
-        
+            Chepy: The Chepy object.
+
         Examples:
             >>> Chepy("aㅎ").to_charcode().o
             ["61", "314e"]
@@ -657,14 +728,14 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_charcode(self, prefix: str = ""):
+    def from_charcode(self, prefix: str = "") -> DataFormatT:
         """Convert array of unicode chars to string
-        
+
         Args:
             prefix (str, optional): Any prefix for the charcode. Ex: \\u or u. Defaults to "".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(["314e", "61", "20", "41"]).from_charcode().o
@@ -678,9 +749,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_decimal(self):
+    def to_decimal(self) -> DataFormatT:
         """Convert charactes to decimal
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -692,11 +763,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_decimal(self):
+    def from_decimal(self) -> DataFormatT:
         """Convert a list of decimal numbers to string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy([12622]).from_decimal().o
@@ -706,9 +777,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_binary(self):
+    def to_binary(self) -> DataFormatT:
         """Convert string characters to binary
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -720,11 +791,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_binary(self):
+    def from_binary(self) -> DataFormatT:
         """Convert a list of binary numbers to string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(["01100001", "01100010", "01100011"]).from_binary().o
@@ -742,9 +813,9 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_octal(self):
+    def to_octal(self) -> DataFormatT:
         """Convert string characters to octal
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -756,11 +827,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_octal(self):
+    def from_octal(self) -> DataFormatT:
         """Convert a list of octal numbers to string
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(["141", "142", "30516"]).from_octal().o
@@ -770,13 +841,13 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_html_entity(self):
+    def to_html_entity(self) -> DataFormatT:
         """Encode html entities
 
         Encode special html characters like & > < etc
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy('https://google.com&a="lol"').to_html_entity().o
@@ -786,13 +857,13 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_html_entity(self):
+    def from_html_entity(self) -> DataFormatT:
         """Decode html entities
 
         Decode special html characters like & > < etc
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("https://google.com&amp;a=&quot;lol&quot;").from_html_entity().o
@@ -802,11 +873,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_punycode(self):
+    def to_punycode(self) -> DataFormatT:
         """Encode to punycode
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("münchen").to_punycode().o
@@ -816,11 +887,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_punycode(self):
+    def from_punycode(self) -> DataFormatT:
         """Decode to punycode
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(b"mnchen-3ya").from_punycode().o
@@ -830,15 +901,15 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def encode_bruteforce(self):
+    def encode_bruteforce(self) -> DataFormatT:
         """Bruteforce the various encoding for a string
 
-        Enumerates all supported text encodings for the input, 
+        Enumerates all supported text encodings for the input,
         allowing you to quickly spot the correct one.
         `Reference <https://docs.python.org/2.4/lib/standard-encodings.html>`__
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("münchen한").encode_bruteforce()
@@ -873,15 +944,15 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def decode_bruteforce(self):
+    def decode_bruteforce(self) -> DataFormatT:
         """Bruteforce the various decoding for a string
 
-        Enumerates all supported text encodings for the input, 
+        Enumerates all supported text encodings for the input,
         allowing you to quickly spot the correct one.
         `Reference <https://docs.python.org/2.4/lib/standard-encodings.html>`__
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("m\\xfcnchen\\ud55c").decode_bruteforce()
@@ -920,11 +991,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def to_braille(self):
+    def to_braille(self) -> DataFormatT:
         """Convery text to six-dot braille symbols
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("secret message").to_braille().o
@@ -935,11 +1006,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def from_braille(self):
+    def from_braille(self) -> DataFormatT:
         """Convery text to six-dot braille symbols
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("⠎⠑⠉⠗⠑⠞⠀⠍⠑⠎⠎⠁⠛⠑").from_braille().o
@@ -950,12 +1021,11 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def trim(self):
+    def trim(self) -> DataFormatT:
         """Trim string. Removes whitespaces
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = self._convert_to_str().strip()
         return self
-
