@@ -1,29 +1,38 @@
-import codecs
-import string
-import itertools
 import base64
 import binascii
-import jwt
+import codecs
+import itertools
+import string
+from typing import TypeVar
+
+import lazy_import
+
+jwt = lazy_import.lazy_module("jwt")
 import pathlib
-import ujson
+
 import pycipher
 import regex as re
+import ujson
 
+AES = lazy_import.lazy_module("Crypto.Cipher.AES")
+ARC4 = lazy_import.lazy_module("Crypto.Cipher.ARC4")
+DES = lazy_import.lazy_module("Crypto.Cipher.DES")
+DES3 = lazy_import.lazy_module("Crypto.Cipher.DES3")
+Blowfish = lazy_import.lazy_module("Crypto.Cipher.Blowfish")
 from Crypto.Util.Padding import pad, unpad
-from Crypto.Cipher import ARC4
-from Crypto.Cipher import DES, DES3, AES
-from Crypto.Cipher import Blowfish
 
 from ..core import ChepyCore, ChepyDecorators
-from .internal.constants import EncryptionConsts
 from ..extras.combinatons import hex_chars
+from .internal.constants import EncryptionConsts
+
+EncryptionEncodingT = TypeVar("EncryptionEncodingT", bound="EncryptionEncoding")
 
 
 class EncryptionEncoding(ChepyCore):
-    """This class handles most operations related to various encryption 
-    related operations. This class inherits the ChepyCore class, and all the 
+    """This class handles most operations related to various encryption
+    related operations. This class inherits the ChepyCore class, and all the
     methods are also available from the Chepy class
-    
+
     Examples:
         >>> from chepy import Chepy
         or
@@ -36,7 +45,9 @@ class EncryptionEncoding(ChepyCore):
     def __check_mode(self, mode) -> None:
         assert mode in ["CBC", "OFB", "CTR", "ECB"], "Not a valid mode."
 
-    def _convert_key(self, key, iv, hex_key, hex_iv):  # pragma: no cover
+    def _convert_key(
+        self, key, iv, hex_key, hex_iv
+    ) -> EncryptionEncodingT:  # pragma: no cover
         if isinstance(key, str):
             key = key.encode()
         if hex_key:
@@ -50,12 +61,12 @@ class EncryptionEncoding(ChepyCore):
         return key, iv
 
     @ChepyDecorators.call_stack
-    def rotate(self, rotate_by: int):
+    def rotate(self, rotate_by: int) -> EncryptionEncodingT:
         """Rotate string by provided number
-        
+
         Args:
             rotate_by (int): Required. Number to rotate by
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -74,10 +85,10 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def rotate_bruteforce(self):
+    def rotate_bruteforce(self) -> EncryptionEncodingT:
         """Brute force rotation from 1 to 26.
         Returned value is a dict where key is the rotation count.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -106,27 +117,27 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def rot_13(self):
+    def rot_13(self) -> EncryptionEncodingT:
         """ROT-13 encoding
-        
-        A simple caesar substitution cipher which rotates alphabet 
+
+        A simple caesar substitution cipher which rotates alphabet
         characters by the specified amount (default 13).
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = codecs.encode(self._convert_to_str(), "rot_13")
         return self
 
     @ChepyDecorators.call_stack
-    def rot_47(self):
+    def rot_47(self) -> EncryptionEncodingT:
         """ROT 47 encoding
-        
-        A slightly more complex variation of a caesar cipher, which includes 
+
+        A slightly more complex variation of a caesar cipher, which includes
         ASCII characters from 33 '!' to 126 '~'. Default rotation: 47.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some").rot_47().output
@@ -143,11 +154,13 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def xor(self, key: str, key_type: str = "hex", ascii: bool = False):
+    def xor(
+        self, key: str, key_type: str = "hex", ascii: bool = False
+    ) -> EncryptionEncodingT:
         """XOR state with a key
 
-        Valid key formats are utf, hex and base64. Simple XOR cipher is a type 
-        of additive cipher based on logical operation xor, which operates according 
+        Valid key formats are utf, hex and base64. Simple XOR cipher is a type
+        of additive cipher based on logical operation xor, which operates according
         to the following principles.
 
         (A * B) + (!A * !B)
@@ -160,14 +173,14 @@ class EncryptionEncoding(ChepyCore):
 
         The main advantage of xor chipher is that the encyption is reversible with t
         he same logical operation.
-        
+
         Args:
             key (str): Required. The key to xor by
             key_type (str, optional): The key type. Valid values are hex, utf and base64. Defaults to "hex".
             ascii (bool, optional): If the input is in ascii format
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("secret").xor(key="secret", key_type="utf").to_hex()
@@ -198,15 +211,15 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def xor_bruteforce(self, length: int = 100):
+    def xor_bruteforce(self, length: int = 100) -> EncryptionEncodingT:
         """Brute force single byte xor
 
-        For multibyte xor bruteforce, use chepy.extras.crypto_extras.xor_bruteforce_multi 
+        For multibyte xor bruteforce, use chepy.extras.crypto_extras.xor_bruteforce_multi
         function
-        
+
         Args:
             length (int, optional): How to bytes to bruteforce. Defaults to 100.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -236,11 +249,11 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def jwt_decode(self):
+    def jwt_decode(self) -> EncryptionEncodingT:
         """Decode a JWT token. Does not verify
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = {
             "payload": jwt.decode(self._convert_to_str(), verify=False),
@@ -249,15 +262,17 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def jwt_verify(self, secret: str, algorithm: list = ["HS256"]):
+    def jwt_verify(
+        self, secret: str, algorithm: list = ["HS256"]
+    ) -> EncryptionEncodingT:
         """Verify JWT token
-        
+
         Args:
             secret (str): Required. Secret key for token
             algorithm (list, optional): Array of valid algorithms. Defaults to ["HS256"]
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = jwt.decode(
             self._convert_to_str(), key=secret, algorithms=algorithm
@@ -265,15 +280,15 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def jwt_sign(self, secret: str, algorithms: str = "HS256"):
+    def jwt_sign(self, secret: str, algorithms: str = "HS256") -> EncryptionEncodingT:
         """Sign a json/dict object in JWT
-        
+
         Args:
             secret (str): Required. Secret to sign with
             algorithms (str, optional): Signing algorithm. Defaults to "HS256".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if isinstance(self.state, dict):
             data = self.state
@@ -288,16 +303,16 @@ class EncryptionEncoding(ChepyCore):
     ):
         """Brute force JWT token secret
 
-        This method will use the provided wordlist to try and bruteforce the 
+        This method will use the provided wordlist to try and bruteforce the
         verification.
-        
+
         Args:
             wordlist (str): Required. Path to a wordlist
             b64_encode (bool, optional): Encoded the words in base64. Defaults to False.
             algorithm (list, optional): Array of valid algorithms. Defaults to ["HS256"].
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         with open(pathlib.Path(wordlist).expanduser().absolute()) as words:
             for word in words:
@@ -318,15 +333,15 @@ class EncryptionEncoding(ChepyCore):
                 return self
 
     @ChepyDecorators.call_stack
-    def rc4_encrypt(self, key: str, hex_key: bool = False):
+    def rc4_encrypt(self, key: str, hex_key: bool = False) -> EncryptionEncodingT:
         """Encrypt raw state with RC4
-        
+
         Args:
             key (str): Required. Secret key
             hex_key (bool, optional): If key is in hex. Defaults to False.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").rc4_encrypt("736563726574", hex_key=True).o
@@ -341,15 +356,15 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def rc4_decrypt(self, key: str, hex_key: bool = False):
+    def rc4_decrypt(self, key: str, hex_key: bool = False) -> EncryptionEncodingT:
         """Decrypt raw state with RC4
-        
+
         Args:
             key (str): Required. Secret key
             hex_key (bool, optional): If key is in hex. Defaults to False.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("9e59bf79a2c0b7d253").hex_to_str().rc4_decrypt("secret").o
@@ -374,23 +389,23 @@ class EncryptionEncoding(ChepyCore):
     ):
         """Encrypt raw state with DES
 
-        DES is a previously dominant algorithm for encryption, and was published 
-        as an official U.S. Federal Information Processing Standard (FIPS). It is 
-        now considered to be insecure due to its small key size. DES uses a key 
-        length of 8 bytes (64 bits).<br>Triple DES uses a key length of 24 bytes. 
-        You can generate a password-based key using one of the KDF operations. 
-        The Initialization Vector should be 8 bytes long. If not entered, it will 
+        DES is a previously dominant algorithm for encryption, and was published
+        as an official U.S. Federal Information Processing Standard (FIPS). It is
+        now considered to be insecure due to its small key size. DES uses a key
+        length of 8 bytes (64 bits).<br>Triple DES uses a key length of 24 bytes.
+        You can generate a password-based key using one of the KDF operations.
+        The Initialization Vector should be 8 bytes long. If not entered, it will
         default to 8 null bytes. Padding: In CBC and ECB mode, PKCS#7 padding will be used.
-        
+
         Args:
             key (str): Required. The secret key
             iv (str, optional): IV for certain modes only. Defaults to '0000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").des_encrypt("70617373776f7264", hex_key=True).o
@@ -432,25 +447,25 @@ class EncryptionEncoding(ChepyCore):
         hex_key: bool = False,
         hex_iv: bool = True,
     ):
-        """Decrypt raw state encrypted with DES. 
+        """Decrypt raw state encrypted with DES.
 
-        DES is a previously dominant algorithm for encryption, and was published 
-        as an official U.S. Federal Information Processing Standard (FIPS). It is 
-        now considered to be insecure due to its small key size. DES uses a key 
-        length of 8 bytes (64 bits).<br>Triple DES uses a key length of 24 bytes. 
-        You can generate a password-based key using one of the KDF operations. 
-        The Initialization Vector should be 8 bytes long. If not entered, it will 
+        DES is a previously dominant algorithm for encryption, and was published
+        as an official U.S. Federal Information Processing Standard (FIPS). It is
+        now considered to be insecure due to its small key size. DES uses a key
+        length of 8 bytes (64 bits).<br>Triple DES uses a key length of 24 bytes.
+        You can generate a password-based key using one of the KDF operations.
+        The Initialization Vector should be 8 bytes long. If not entered, it will
         default to 8 null bytes. Padding: In CBC and ECB mode, PKCS#7 padding will be used.
-        
+
         Args:
             key (str): Required. The secret key
             iv (str, optional): IV for certain modes only. Defaults to '0000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("1ee5cb52954b211d1acd6e79c598baac").hex_to_str().des_decrypt("password").o
@@ -489,22 +504,22 @@ class EncryptionEncoding(ChepyCore):
     ):
         """Encrypt raw state with Triple DES
 
-        Triple DES applies DES three times to each block to increase key size. Key: 
-        Triple DES uses a key length of 24 bytes (192 bits).<br>DES uses a key length 
-        of 8 bytes (64 bits).<br><br>You can generate a password-based key using one 
-        of the KDF operations. IV: The Initialization Vector should be 8 bytes long. 
-        If not entered, it will default to 8 null bytes. Padding: In CBC and ECB 
+        Triple DES applies DES three times to each block to increase key size. Key:
+        Triple DES uses a key length of 24 bytes (192 bits).<br>DES uses a key length
+        of 8 bytes (64 bits).<br><br>You can generate a password-based key using one
+        of the KDF operations. IV: The Initialization Vector should be 8 bytes long.
+        If not entered, it will default to 8 null bytes. Padding: In CBC and ECB
         mode, PKCS#7 padding will be used.
-        
+
         Args:
             key (str): Required. The secret key
             iv (str, optional): IV for certain modes only. Defaults to '0000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").triple_des_encrypt("super secret password !!", mode="ECB").o
@@ -541,24 +556,24 @@ class EncryptionEncoding(ChepyCore):
         hex_key: bool = False,
         hex_iv: bool = True,
     ):
-        """Decrypt raw state encrypted with DES. 
+        """Decrypt raw state encrypted with DES.
 
-        Triple DES applies DES three times to each block to increase key size. Key: 
-        Triple DES uses a key length of 24 bytes (192 bits).<br>DES uses a key length 
-        of 8 bytes (64 bits).<br><br>You can generate a password-based key using one 
-        of the KDF operations. IV: The Initialization Vector should be 8 bytes long. 
-        If not entered, it will default to 8 null bytes. Padding: In CBC and ECB 
+        Triple DES applies DES three times to each block to increase key size. Key:
+        Triple DES uses a key length of 24 bytes (192 bits).<br>DES uses a key length
+        of 8 bytes (64 bits).<br><br>You can generate a password-based key using one
+        of the KDF operations. IV: The Initialization Vector should be 8 bytes long.
+        If not entered, it will default to 8 null bytes. Padding: In CBC and ECB
         mode, PKCS#7 padding will be used.
-        
+
         Args:
             key (str): Required. The secret key
             iv (str, optional): IV for certain modes only. Defaults to '0000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("f8b27a0d8c837edce87dd13a1ab41f96")
@@ -600,29 +615,29 @@ class EncryptionEncoding(ChepyCore):
     ):
         """Encrypt raw state with AES
 
-        Advanced Encryption Standard (AES) is a U.S. Federal Information Processing 
-        Standard (FIPS). It was selected after a 5-year process where 15 competing 
+        Advanced Encryption Standard (AES) is a U.S. Federal Information Processing
+        Standard (FIPS). It was selected after a 5-year process where 15 competing
         designs were evaluated.
-        
-        key: The following algorithms will be used based on the size of the 
+
+        key: The following algorithms will be used based on the size of the
             16 bytes = AES-128
             24 bytes = AES-192
             32 bytes = AES-256
-        
-        You can generate a password-based key using one of the KDF operations. 
-        IV: The Initialization Vector should be 16 bytes long. If not entered, it will 
+
+        You can generate a password-based key using one of the KDF operations.
+        IV: The Initialization Vector should be 16 bytes long. If not entered, it will
         default to 16 null bytes. Padding: In CBC and ECB mode, PKCS#7 padding will be used.
-        
+
         Args:
             key (str): Required. The secret key
-            iv (str, optional): IV for certain modes only. 
+            iv (str, optional): IV for certain modes only.
                 Defaults to '00000000000000000000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").aes_encrypt("secret password!", mode="ECB").o
@@ -667,32 +682,32 @@ class EncryptionEncoding(ChepyCore):
         hex_key: bool = False,
         hex_iv: bool = True,
     ):
-        """Decrypt raw state encrypted with DES. 
+        """Decrypt raw state encrypted with DES.
+
+        Advanced Encryption Standard (AES) is a U.S. Federal Information Processing
+        Standard (FIPS). It was selected after a 5-year process where 15 competing
+        designs were evaluated.<br><br><b>Key:</b> The following algorithms will
+        be used based on the size of the
 
-        Advanced Encryption Standard (AES) is a U.S. Federal Information Processing 
-        Standard (FIPS). It was selected after a 5-year process where 15 competing 
-        designs were evaluated.<br><br><b>Key:</b> The following algorithms will 
-        be used based on the size of the 
-        
         key:
             16 bytes = AES-128
             24 bytes = AES-192
             32 bytes = AES-256
-        
-        You can generate a password-based key using one of the KDF operations. 
-        IV: The Initialization Vector should be 16 bytes long. If not entered, it will 
+
+        You can generate a password-based key using one of the KDF operations.
+        IV: The Initialization Vector should be 16 bytes long. If not entered, it will
         default to 16 null bytes. Padding: In CBC and ECB mode, PKCS#7 padding will be used.
-        
+
         Args:
             key (str): Required. The secret key
-            iv (str, optional): IV for certain modes only. 
+            iv (str, optional): IV for certain modes only.
                 Defaults to '00000000000000000000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("5fb8c186394fc399849b89d3b6605fa3")
@@ -742,8 +757,8 @@ class EncryptionEncoding(ChepyCore):
     ):
         """Encrypt raw state with Blowfish
 
-        Blowfish is a symmetric-key block cipher designed in 1993 by 
-        Bruce Schneier and included in a large number of cipher suites 
+        Blowfish is a symmetric-key block cipher designed in 1993 by
+        Bruce Schneier and included in a large number of cipher suites
         and encryption products. AES now receives more attention.
         IV: The Initialization Vector should be 8 bytes long.
 
@@ -753,9 +768,9 @@ class EncryptionEncoding(ChepyCore):
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some data").blowfish_encrypt("password", mode="ECB").o
@@ -794,21 +809,21 @@ class EncryptionEncoding(ChepyCore):
     ):
         """Encrypt raw state with Blowfish
 
-        Blowfish is a symmetric-key block cipher designed in 1993 by 
-        Bruce Schneier and included in a large number of cipher suites 
+        Blowfish is a symmetric-key block cipher designed in 1993 by
+        Bruce Schneier and included in a large number of cipher suites
         and encryption products. AES now receives more attention.
         IV: The Initialization Vector should be 8 bytes long.
-        
+
         Args:
             key (str): Required. The secret key
-            iv (str, optional): IV for certain modes only. 
+            iv (str, optional): IV for certain modes only.
                 Defaults to '00000000000000000000000000000000'.
             mode (str, optional): Encryption mode. Defaults to 'CBC'.
             hex_key (bool, optional): If the secret key is a hex string. Defaults to False.
             hex_iv (bool, optional): If the IV is a hex string. Defaults to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("d9b0a79853f13960fcee3cae16e27884")
@@ -840,14 +855,14 @@ class EncryptionEncoding(ChepyCore):
             return self
 
     @ChepyDecorators.call_stack
-    def vigenere_encode(self, key: str):
+    def vigenere_encode(self, key: str) -> EncryptionEncodingT:
         """Encode with Vigenere ciper
-        
+
         Args:
             key (str): Required. The secret key
-        
+
         Returns:
-            Chepy: The Chepy oject. 
+            Chepy: The Chepy oject.
 
         Examples:
             >>> Chepy("secret").vigenere_encode("secret").o
@@ -857,14 +872,14 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def vigenere_decode(self, key: str):
+    def vigenere_decode(self, key: str) -> EncryptionEncodingT:
         """Decode Vigenere ciper
-        
+
         Args:
             key (str): Required. The secret key
-        
+
         Returns:
-            Chepy: The Chepy oject. 
+            Chepy: The Chepy oject.
 
         Examples:
             >>> Chepy("KIEIIM").vigenere_decode("secret").o
@@ -874,15 +889,15 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def affine_encode(self, a: int = 1, b: int = 1):
+    def affine_encode(self, a: int = 1, b: int = 1) -> EncryptionEncodingT:
         """Encode with Affine ciper
-        
+
         Args:
             a (int, optional): Multiplier value. Defaults to 1
             b (int, optional): Additive value. Defaults to 1
-        
+
         Returns:
-            Chepy: The Chepy oject. 
+            Chepy: The Chepy oject.
 
         Examples:
             >>> Chepy("secret").affine_encode().o
@@ -892,15 +907,15 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def affine_decode(self, a: int = 1, b: int = 1):
+    def affine_decode(self, a: int = 1, b: int = 1) -> EncryptionEncodingT:
         """Decode Affine ciper
-        
+
         Args:
             a (int, optional): Multiplier value. Defaults to 1
             b (int, optional): Additive value. Defaults to 1
-        
+
         Returns:
-            Chepy: The Chepy oject. 
+            Chepy: The Chepy oject.
 
         Examples:
             >>> Chepy("TFDSFU").affine_decode().o
@@ -910,11 +925,11 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def atbash_encode(self):
+    def atbash_encode(self) -> EncryptionEncodingT:
         """Encode with Atbash ciper
-        
+
         Returns:
-            Chepy: The Chepy oject. 
+            Chepy: The Chepy oject.
 
         Examples:
             >>> Chepy("secret").atbash_encode().o
@@ -924,11 +939,11 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def atbash_decode(self):
+    def atbash_decode(self) -> EncryptionEncodingT:
         """Decode Atbash ciper
-        
+
         Returns:
-            Chepy: The Chepy oject. 
+            Chepy: The Chepy oject.
 
         Examples:
             >>> Chepy("hvxivg").atbash_decode().o
@@ -946,15 +961,15 @@ class EncryptionEncoding(ChepyCore):
         word_delim: str = "\n",
     ):
         """Encode string to morse code
-        
+
         Args:
             dot (str, optional): The char for dot. Defaults to ".".
             dash (str, optional): The char for dash. Defaults to "-".
             letter_delim (str, optional): Letter delimiter. Defaults to " ".
             word_delim (str, optional): Word delimiter. Defaults to "\\n".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         encode = ""
         morse_code_dict = EncryptionConsts.MORSE_CODE_DICT
@@ -976,15 +991,15 @@ class EncryptionEncoding(ChepyCore):
         word_delim: str = "\n",
     ):
         """Decode morse code
-        
+
         Args:
             dot (str, optional): The char for dot. Defaults to ".".
             dash (str, optional): The char for dash. Defaults to "-".
             letter_delim (str, optional): Letter delimiter. Defaults to " ".
             word_delim (str, optional): Word delimiter. Defaults to "\\n".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         decode = ""
         morse_code_dict = EncryptionConsts.MORSE_CODE_DICT
