@@ -1,27 +1,32 @@
 import collections
+import ipaddress
 import socket
 import ssl
-import ipaddress
-import regex as re
 import urllib.parse as _py_urlparse
+from typing import TypeVar
+
+import regex as re
+
 from ..core import ChepyCore, ChepyDecorators
 
+NetworkingT = TypeVar("NetworkingT", bound="Networking")
+
 
 class Networking(ChepyCore):
     def __init__(self, *data):
         super().__init__(*data)
 
     @ChepyDecorators.call_stack
-    def defang_url(self):
+    def defang_url(self) -> NetworkingT:
         """Make a URL harmless
-        
-        Takes a Universal Resource Locator (URL) and 'Defangs' it; 
-        meaning the URL becomes invalid, neutralising the risk of accidentally 
-        clicking on a malicious link. This is often used when dealing with 
+
+        Takes a Universal Resource Locator (URL) and 'Defangs' it;
+        meaning the URL becomes invalid, neutralising the risk of accidentally
+        clicking on a malicious link. This is often used when dealing with
         malicious links or IOCs.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("https://app.google.com/?lol=some data&a=1").defang_url().o
@@ -32,11 +37,11 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def refang_url(self):
+    def refang_url(self) -> NetworkingT:
         """Refangs a URL so that it is clickable
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("hxxps://app[.]google[.]com/?lol=some data&a=1").refang_url().o
@@ -47,20 +52,20 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def defang_ip(self):
+    def defang_ip(self) -> NetworkingT:
         """Make an IP address harmless
-        
-        Takes a IPv4 or IPv6 address and 'Defangs' it, meaning the 
-        IP becomes invalid, removing the risk of accidentally utilising 
+
+        Takes a IPv4 or IPv6 address and 'Defangs' it, meaning the
+        IP becomes invalid, removing the risk of accidentally utilising
         it as an IP address.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("2001:4860:4860::8844").defang_ip().o
             "2001[:]4860[:]4860[:][:]8844"
-            
+
             >>> Chepy("127.0.0.1").defang_ip().o
             "127[.]0[.]0[.]1"
         """
@@ -71,11 +76,11 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def refang_ip(self):
+    def refang_ip(self) -> NetworkingT:
         """Refangs an IP address
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("127[.]0[.]0[.]1").refang_ip().o
@@ -85,9 +90,9 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def parse_uri(self):
+    def parse_uri(self) -> NetworkingT:
         """Parse a URI
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -114,9 +119,9 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def parse_ip_range(self):
+    def parse_ip_range(self) -> NetworkingT:
         """Enumerate IP address in a CIDR range
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -136,9 +141,9 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def parse_ipv6(self):
+    def parse_ipv6(self) -> NetworkingT:
         """Get longhand and shorthand of IPv6
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -154,12 +159,12 @@ class Networking(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def get_ssl_cert(self, port: int = 443):
+    def get_ssl_cert(self, port: int = 443) -> NetworkingT:
         """Get the server side SSL certificate for a domain
-        
+
         Args:
             port (int, optional): Server port. Defaults to 443.
-        
+
         Returns:
             Chepy: The Chepy object
 
