@@ -1,8 +1,14 @@
-from OpenSSL import crypto as _pyssl_crypto
-from Crypto.PublicKey import RSA
+from typing import TypeVar
+
+import lazy_import
+
+RSA = lazy_import.lazy_module("Crypto.PublicKey.RSA")
+OpenSSL = lazy_import.lazy_module("OpenSSL")
 
 from ..core import ChepyCore, ChepyDecorators
 
+PublickeyT = TypeVar("PublickeyT", bound="Publickey")
+
 
 class Publickey(ChepyCore):
     def __init__(self, *data):
@@ -41,16 +47,16 @@ class Publickey(ChepyCore):
         return info
 
     @ChepyDecorators.call_stack
-    def parse_x509_pem(self):
+    def parse_x509_pem(self) -> PublickeyT:
         """Parse X509 cert in PEM format
-        
-        X.509 is an ITU-T standard for a public key infrastructure (PKI) 
-        and Privilege Management Infrastructure (PMI). It is commonly involved 
-        with SSL/TLS security. This operation displays the contents of 
+
+        X.509 is an ITU-T standard for a public key infrastructure (PKI)
+        and Privilege Management Infrastructure (PMI). It is commonly involved
+        with SSL/TLS security. This operation displays the contents of
         a certificate in a human readable format, similar to the openssl command line tool.
-        
+
         Returns:
-            Chepy: A Chepy object. 
+            Chepy: A Chepy object.
 
         Examples:
             >>> Chepy(path).load_file().parse_x509_pem().o
@@ -71,72 +77,74 @@ class Publickey(ChepyCore):
                 "pubkey": {"bits": 1024},
             }
         """
-        cert = _pyssl_crypto.load_certificate(
-            _pyssl_crypto.FILETYPE_PEM, self._convert_to_str()
+        cert = OpenSSL.crypto.load_certificate(
+            OpenSSL.crypto.FILETYPE_PEM, self._convert_to_str()
         )
         info = self._convert_cert_to_obj(cert)
         self.state = info
         return self
 
     @ChepyDecorators.call_stack
-    def parse_x509_der_hex(self):
+    def parse_x509_der_hex(self) -> PublickeyT:
         """Parse X509 cert in DER format
-        
-        X.509 is an ITU-T standard for a public key infrastructure (PKI) 
-        and Privilege Management Infrastructure (PMI). It is commonly involved 
-        with SSL/TLS security.<br><br>This operation displays the contents of 
+
+        X.509 is an ITU-T standard for a public key infrastructure (PKI)
+        and Privilege Management Infrastructure (PMI). It is commonly involved
+        with SSL/TLS security.<br><br>This operation displays the contents of
         a certificate in a human readable format, similar to the openssl command line tool.
-        
+
         Returns:
-            Chepy: A Chepy object. 
+            Chepy: A Chepy object.
         """
-        cert = _pyssl_crypto.load_certificate(
-            _pyssl_crypto.FILETYPE_ASN1, self._convert_to_bytes()
+        cert = OpenSSL.crypto.load_certificate(
+            OpenSSL.crypto.FILETYPE_ASN1, self._convert_to_bytes()
         )
         info = self._convert_cert_to_obj(cert)
         self.state = info
         return self
 
     @ChepyDecorators.call_stack
-    def public_from_x509(self):
+    def public_from_x509(self) -> PublickeyT:
         """Get public key from x509 certificate
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
-        crt_obj = _pyssl_crypto.load_certificate(_pyssl_crypto.FILETYPE_PEM, self.state)
+        crt_obj = OpenSSL.crypto.load_certificate(
+            OpenSSL.crypto.FILETYPE_PEM, self.state
+        )
         pub_key_object = crt_obj.get_pubkey()
-        pub_key_string = _pyssl_crypto.dump_publickey(
-            _pyssl_crypto.FILETYPE_PEM, pub_key_object
+        pub_key_string = OpenSSL.crypto.dump_publickey(
+            OpenSSL.crypto.FILETYPE_PEM, pub_key_object
         )
         self.state = pub_key_string
         return self
 
     @ChepyDecorators.call_stack
-    def pem_to_der_hex(self):
+    def pem_to_der_hex(self) -> PublickeyT:
         """Convert PEM cert to DER format
-        
-        Converts PEM (Privacy Enhanced Mail) format to a hexadecimal 
+
+        Converts PEM (Privacy Enhanced Mail) format to a hexadecimal
         DER (Distinguished Encoding Rules) string.
-        
+
         Returns:
             Chepy: The Chepy object.
         """
-        cert_pem = _pyssl_crypto.load_certificate(
-            _pyssl_crypto.FILETYPE_PEM, self.state
+        cert_pem = OpenSSL.crypto.load_certificate(
+            OpenSSL.crypto.FILETYPE_PEM, self.state
         )
-        self.state = _pyssl_crypto.dump_certificate(
-            _pyssl_crypto.FILETYPE_ASN1, cert_pem
+        self.state = OpenSSL.crypto.dump_certificate(
+            OpenSSL.crypto.FILETYPE_ASN1, cert_pem
         )
         return self
 
     @ChepyDecorators.call_stack
-    def der_hex_to_pem(self):
+    def der_hex_to_pem(self) -> PublickeyT:
         """Convert DER format to PEM cert.
-        
-        Converts a hexadecimal DER (Distinguished Encoding Rules) 
+
+        Converts a hexadecimal DER (Distinguished Encoding Rules)
         string into PEM (Privacy Enhanced Mail) format.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -154,20 +162,20 @@ class Publickey(ChepyCore):
             igbV1IJdKTBAiZzaOQ==
             -----END CERTIFICATE-----
         """
-        cert_pem = _pyssl_crypto.load_certificate(
-            _pyssl_crypto.FILETYPE_ASN1, self._convert_to_bytes()
+        cert_pem = OpenSSL.crypto.load_certificate(
+            OpenSSL.crypto.FILETYPE_ASN1, self._convert_to_bytes()
         )
-        self.state = _pyssl_crypto.dump_certificate(
-            _pyssl_crypto.FILETYPE_PEM, cert_pem
+        self.state = OpenSSL.crypto.dump_certificate(
+            OpenSSL.crypto.FILETYPE_PEM, cert_pem
         )
         return self
 
     @ChepyDecorators.call_stack
-    def parse_public_pem(self):
+    def parse_public_pem(self) -> PublickeyT:
         """Parse pubkey PEM to get n and e
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("tests/files/public.pem").load_file().parse_public_pem().get_by_key("e").o
@@ -178,11 +186,11 @@ class Publickey(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def parse_private_pem(self):
+    def parse_private_pem(self) -> PublickeyT:
         """Parse private key PEM
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         key = RSA.importKey(self.state)
         self.state = {
@@ -196,25 +204,24 @@ class Publickey(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def dump_pkcs12_cert(self, password: str):
+    def dump_pkcs12_cert(self, password: str) -> PublickeyT:
         """Get the private key and cert from pkcs12 cert
-        
+
         Args:
             password (str): Password for certificate
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if isinstance(password, str):
             password = password.encode()
-        pk12 = _pyssl_crypto.load_pkcs12(self._convert_to_bytes(), password)
+        pk12 = OpenSSL.crypto.load_pkcs12(self._convert_to_bytes(), password)
         self.state = {
-            "private": _pyssl_crypto.dump_privatekey(
-                _pyssl_crypto.FILETYPE_PEM, pk12.get_privatekey()
+            "private": OpenSSL.crypto.dump_privatekey(
+                OpenSSL.crypto.FILETYPE_PEM, pk12.get_privatekey()
             ),
-            "cert": _pyssl_crypto.dump_certificate(
-                _pyssl_crypto.FILETYPE_PEM, pk12.get_certificate()
+            "cert": OpenSSL.crypto.dump_certificate(
+                OpenSSL.crypto.FILETYPE_PEM, pk12.get_certificate()
             ),
         }
         return self
-
