@@ -1,13 +1,16 @@
 import difflib
-import regex as re
-import exrex
 from collections import OrderedDict
-from typing import Any, Union
+from typing import Any, TypeVar, Union
+
+import chepy.modules.internal.colors as _int_colors
+import exrex
 import pydash
+import regex as re
 
 from ..core import ChepyCore, ChepyDecorators
 from .exceptions import StateNotDict, StateNotList
-import chepy.modules.internal.colors as _int_colors
+
+UtilsT = TypeVar("UtilsT", bound="Utils")
 
 
 class Utils(ChepyCore):
@@ -15,12 +18,12 @@ class Utils(ChepyCore):
         super().__init__(*data)
 
     @ChepyDecorators.call_stack
-    def reverse(self, count: int = 1):
+    def reverse(self, count: int = 1) -> UtilsT:
         """Reverses a string
-        
+
         Args:
             count (int, optional): Reverse by the number of characters indicated in count. Defaults to 1.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -40,7 +43,7 @@ class Utils(ChepyCore):
             return self
 
     @ChepyDecorators.call_stack
-    def count_occurances(self, regex: str, case_sensitive: bool = False):
+    def count_occurances(self, regex: str, case_sensitive: bool = False) -> UtilsT:
         """Counts occurances of the regex.
 
         Counts the number of times the provided string occurs.
@@ -73,14 +76,14 @@ class Utils(ChepyCore):
         form_feeds: bool = True,
     ):
         """Remove whitespace from a string
-        
+
         Args:
             spaces (bool, optional): Remove spaces. Defaults to True.
             carriage_return (bool, optional): Remove carriage return \\r. Defaults to True.
             line_feeds (bool, optional): Remove line feeds \\n. Defaults to True.
             tabs (bool, optional): Temove tabs \\t. Defaults to True.
             form_feeds (bool, optional): Remove form feeds \\f. Defaults to True.
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -99,9 +102,9 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def remove_nullbytes(self):
+    def remove_nullbytes(self) -> UtilsT:
         """Remove null \\x00 byes from binary data
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -119,7 +122,7 @@ class Utils(ChepyCore):
         extended: bool = False,
     ):
         """Regex search on current data
-        
+
         Args:
             pattern (str): Required. The regex pattern to search by
             ignore_case (bool, optional): Set case insentive flag. Defaults to False.
@@ -127,7 +130,7 @@ class Utils(ChepyCore):
             dotall (bool, optional): `.` matches newline. Defaults to False.
             unicode (bool, optional): Match unicode characters. Defaults to False.
             extended (bool, optional): Ignore whitespace. Defaults to False.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -150,13 +153,13 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def split_by(self, pattern: str = "\n", trim=True):
+    def split_by(self, pattern: str = "\n", trim=True) -> UtilsT:
         """Split a string by the given pattern
-        
+
         Args:
             pattern (str, optional): Pattern to split by. Defaults to '\\n'.
             time (bool, optional): Trim whitespace after split. Defaults to True
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -169,14 +172,14 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def split_by_n(self, n: int):
+    def split_by_n(self, n: int) -> UtilsT:
         """Split a string by n characters.
-        
+
         Args:
             n (int): n from 0
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some string").split_by_n(2).o[2]
@@ -186,17 +189,17 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def select_every_n(self, n: int, start: int = 0):
-        """Select every nth item from a list or string. 
+    def select_every_n(self, n: int, start: int = 0) -> UtilsT:
+        """Select every nth item from a list or string.
 
         Index starts at 0
-        
+
         Args:
             n (int): n from 0
             start (int): starting position. Defaults to 0.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy(["a", 1, "lol", "b", True]).select_every_n(3)
@@ -206,12 +209,12 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def unique(self):
+    def unique(self) -> UtilsT:
         """Get an array of unique list items
-        
+
         Raises:
             StateNotList: If state is not a list
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -220,15 +223,15 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def sort_list(self, reverse: bool = False):
+    def sort_list(self, reverse: bool = False) -> UtilsT:
         """Sort a list
-        
+
         Args:
             reverse (bool, optional): In reverse order. Defaults to False.
-        
+
         Raises:
             StateNotList: If state is not list
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -243,14 +246,14 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def sort_dict_key(self, reverse: bool = False):
+    def sort_dict_key(self, reverse: bool = False) -> UtilsT:
         """Sort a dictionary by key
-        
+
         Args:
             reverse (bool, optional): Reverse sort order. Defaults to False.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy({'z': 'string', 'a': True, 'zz': 1, 'aaa': {'bb': 'data'}, 'ccc': [1,'a']})
@@ -262,12 +265,12 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def sort_dict_value(self, reverse=False):
+    def sort_dict_value(self, reverse=False) -> UtilsT:
         """Sort dictionary by value
-        
+
         Args:
             reverse (bool, optional): Reverse sort order. Defaults to False.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -277,24 +280,31 @@ class Utils(ChepyCore):
             {'zz': '1', 'a': 'True', 'ccc': [1, 'a'], 'z': 'string', 'aaa': {'bb': 'data'}}
         """
         assert isinstance(self.state, dict), StateNotDict()
-        self.state = dict(
-            OrderedDict(
-                sorted(self.state.items(), reverse=reverse, key=lambda x: str(x[1]))
+        try:
+            self.state = dict(
+                OrderedDict(
+                    sorted(self.state.items(), reverse=reverse, key=lambda x: x[1])
+                )
+            )
+        except:
+            self.state = dict(
+                OrderedDict(
+                    sorted(self.state.items(), reverse=reverse, key=lambda x: str(x[1]))
+                )
             )
-        )
         return self
 
     @ChepyDecorators.call_stack
-    def filter_list(self, by: Union[str, dict], regex: bool = True):
+    def filter_list(self, by: Union[str, dict], regex: bool = True) -> UtilsT:
         """Filter a list by a string regex or dict key
-        
+
         Args:
             by (Union[str, dict]): If string, supports regex. Or dictionary
             regex (bool, optional): If pattern is a regex. Defaults to True
-        
+
         Raises:
             StateNotList: If state is not a list
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -313,17 +323,17 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def filter_list_by_length(self, length: int, exact: bool = False):
-        """Filter a list by length by specifying minimum length. 
+    def filter_list_by_length(self, length: int, exact: bool = False) -> UtilsT:
+        """Filter a list by length by specifying minimum length.
+
+        It will also return items that exceed the specified length.
 
-        It will also return items that exceed the specified length. 
-        
         Args:
             length (int): Minimum length to match
             exact (bool): Match exact length
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         assert isinstance(self.state, list), StateNotList()
         if exact:
@@ -333,14 +343,14 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def filter_dict_key(self, by: str):
+    def filter_dict_key(self, by: str) -> UtilsT:
         """Filter dictionary by key
-        
+
         Args:
-            by (str): Required. Key to filter by. 
-        
+            by (str): Required. Key to filter by.
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy({'some': 'dict', 'another': 'val'}).filter_dict_key('ano')
@@ -353,16 +363,16 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def filter_dict_value(self, by: str):
-        """Filter dictionary by value. 
+    def filter_dict_value(self, by: str) -> UtilsT:
+        """Filter dictionary by value.
+
+        This method does descend into nested dictionary values.
 
-        This method does descend into nested dictionary values. 
-        
         Args:
-            by (str): Required. Value to filter by. 
-        
+            by (str): Required. Value to filter by.
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy({'some': 'dict', 'another': 'val'}).filter_dict_value('val')
@@ -375,13 +385,13 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def slice(self, start: int = 0, end: int = None):
+    def slice(self, start: int = 0, end: int = None) -> UtilsT:
         """Returns the specified slice
-        
+
         Args:
             start (int, optional): Start position. Defaults to 0.
             end (int, optional): End position. Defaults to None.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -393,14 +403,14 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def find_replace(self, pattern: str, repl: str, ignore_case=True):
+    def find_replace(self, pattern: str, repl: str, ignore_case=True) -> UtilsT:
         """Replace matched pattern with repln
-        
+
         Args:
             pattern (str): Required. Pattern to search
             repl (str): Required. Pattern to match
             ignore_case (bool, optional): Case insensitive. Defaults to True.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -415,9 +425,9 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def escape_string(self):
+    def escape_string(self) -> UtilsT:
         """Escape all special characters in a string
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -425,9 +435,9 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def unescape_string(self):
+    def unescape_string(self) -> UtilsT:
         """Unescape \\ from a string
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -439,9 +449,9 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def color_hex_to_rgb(self):
+    def color_hex_to_rgb(self) -> UtilsT:
         """Convert hex color to rgb
-        
+
         Returns:
             Chepy: The Chepy object.
         """
@@ -459,18 +469,18 @@ class Utils(ChepyCore):
         swap: bool = False,
     ):
         """Diff state with another state or buffer
-        
+
         Args:
             state (int, optional): Index of state to compare against. Defaults to None.
             buffer (int, optional): Index of buffer to compare against. Defaults to None.
             colors (int, optional): Show colored diff. Defaults to False.
             swap (int, optional): Swap the diff order. Defaults to False.
-        
+
         Raises:
             TypeError: If both state and buffer is set to True.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("first string", "First $trin")
@@ -495,7 +505,7 @@ class Utils(ChepyCore):
         else:
             matcher = difflib.SequenceMatcher(None, data, self._convert_to_str())
 
-        def process_tag(tag, i1, i2, j1, j2):  # pragma: no cover
+        def process_tag(tag, i1, i2, j1, j2) -> UtilsT:  # pragma: no cover
             if tag == "replace":
                 if colors:
                     return _int_colors.blue(matcher.b[j1:j2])
@@ -519,21 +529,21 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def pad(self, width: int, direction: str = "left", char: str = " "):
+    def pad(self, width: int, direction: str = "left", char: str = " ") -> UtilsT:
         """Pad string with a character
-        
+
         Args:
-            width (int): Required. Total length of string. The padding is calculated from 
+            width (int): Required. Total length of string. The padding is calculated from
                 the length of state minus width.
             direction (str, optional): Padding direction. left or right. Defaults to 'left'.
             char (str, optional): Char to fill with. Defaults to ' '.
-        
+
         Returns:
             Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("lol").pad(5, char="a")
-            lol # this is because "lol" is len 3, and padding is 5 - 2, which is 2, so no 
+            lol # this is because "lol" is len 3, and padding is 5 - 2, which is 2, so no
             padding is added
             >>> c = Chepy("lol").pad(8, char="a")
             lolaa # 8 - 3 so the output is padded for 5 chars
@@ -555,38 +565,37 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def count(self):
+    def count(self) -> UtilsT:
         """Count anything
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = pydash.count_by(self.state)
         return self
 
     @ChepyDecorators.call_stack
-    def set(self):
+    def set(self) -> UtilsT:
         """Get an array of unique values
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = list(set(self.state))
         return self
 
     @ChepyDecorators.call_stack
-    def regex_to_str(self, all_combo: bool = False):
+    def regex_to_str(self, all_combo: bool = False) -> UtilsT:
         """Convert a regex to a matching string
-        
+
         Args:
             all_combo (bool, optional): Generate all combos that match regex. Defaults to False.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if all_combo:
             self.state = list(exrex.generate(self._convert_to_str()))
         else:
             self.state = exrex.getone(self._convert_to_str())
         return self
-
